@@ -6,7 +6,9 @@ use autodie;
 use App::Fasops -command;
 use App::Fasops::Common;
 
-use constant abstract => 'scan blocked fasta files and output all species names';
+sub abstract {
+    return 'scan blocked fasta files and output all species names';
+}
 
 sub opt_spec {
     return (
@@ -23,8 +25,13 @@ sub usage_desc {
 sub description {
     my $desc;
     $desc .= ucfirst(abstract) . ".\n";
-    $desc .= "\t<infiles> are blocked fasta files, .fas.gz is supported.\n";
-    $desc .= "\tinfile == stdin means reading from STDIN\n";
+    $desc .= <<'MARKDOWN';
+
+* <infiles> are paths to axt files, .axt.gz is supported
+* infile == stdin means reading from STDIN
+
+MARKDOWN
+
     return $desc;
 }
 
